@@ -7,7 +7,7 @@ use utf8;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-01-26'; # DATE
 our $DIST = 'BorderStyles-Standard'; # DIST
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
 our %BORDER = (
     v => 2,
@@ -15,7 +15,7 @@ our %BORDER = (
     chars => [
         ['┌','─','┬','┐'], # 0
         ['│','│','│'],     # 1
-        ['╞','═','╪','╡', '╤','╧','├','┤'], # 2
+        ['╞','═','╪','╡', '╤','╧','╞','╡'], # 2
         ['│','│','│'],     # 3
         ['├','─','┼','┤', '┬','┴','├','┤'], # 4
         ['└','─','┴','┘'], # 5
@@ -23,7 +23,7 @@ our %BORDER = (
         [], # 6
         [], # 7
 
-        ['╞','═','╪','╡', '╤','╧','╞','╡'], # 8
+        ['├','─','┼','┤', '┬','┴','├','┤'], # 8
     ],
     utf8 => 1,
 );
@@ -43,7 +43,7 @@ BorderStyle::UTF8::SingleLineDoubleAfterHeader - Just like UTF8::SingleLine but
 
 =head1 VERSION
 
-This document describes version 0.010 of BorderStyle::UTF8::SingleLineDoubleAfterHeader (from Perl distribution BorderStyles-Standard), released on 2022-01-26.
+This document describes version 0.011 of BorderStyle::UTF8::SingleLineDoubleAfterHeader (from Perl distribution BorderStyles-Standard), released on 2022-01-26.
 
 =head1 SYNOPSIS
 
